-- Program: Font Demo
-- SDK: Corona - 09/12/11
-- Author: Andrew Burch
-- Date: 16/07/2012
-- Site: http://www.newhighscore.net
-- Contact: andrew.burch@newhighscore.net
-- Notes: Cycle through available fonts
--

local button = require('ui.button')
local config = require('config.buttonconfig')
local eventsystem = require('event.eventsystem')


-- optimisations
local _sfmt = string.format


-- hide the status bar
display.setStatusBar(display.HiddenStatusBar)

local contentHeight = display.contentHeight
local contentWidth = display.contentWidth
local halfContentHeight = contentHeight * 0.5
local halfContentWidth = contentWidth * 0.5
local TopLeft = display.TopLeftReferencePoint
local Centred = display.CenterReferencePoint

-- grab available font names
local fontNames = native.getFontNames()
local fontIndex = 1
local totalFound = #fontNames

-- local helper functions
local function formatIndex(index)
	return _sfmt('%d of %d', index, totalFound)
end

local function createFont(dg, name)
	local obj = display.newText(dg, name, 1, halfContentHeight, name, 18)
	obj.x = halfContentWidth
	obj:setTextColor(230, 230, 230)
	obj:setReferencePoint(Centred)
	return obj
end


-- initialise local event system
local eventSystem = eventsystem.new()


-- initialise display objects
local dg = display.newGroup()
local font = native.SystemFont

local indexText = display.newText(dg, formatIndex(1), contentWidth - 45, contentHeight - 15, font, 10)
indexText:setTextColor(200, 200, 200)
indexText:setReferencePoint(TopLeft)

local exampleText = createFont(dg, fontNames[1])

-- initialise button controls
for _, v in ipairs(config.demoButtons) do
	local btn = button.new()
	btn:initialise {
			top = v.top,
			left = v.left,
			width = config.buttonWidth,
			height = config.buttonHeight,
			strokeWidth = config.strokeWidth,
			fontSize = config.fontSize,
			fillColour = config.fillColour,
			strokeColour = config.strokeColour,
			text = v.btnText,
		}
		
	btn:registerWithParent(dg)

	btn:addEventListener('touch', function(event)
						local phase = event.phase
						if phase ~= 'began' then
							return
						end 

						eventSystem:addEvent {
									name = v.eventType,
									indexInc = v.indexInc,
									time = event.time,
								}								
						
						return true
					end)
end


-- add local event listeners
eventSystem:registerEventListener(dg, 'ChangeFontEvent', function(event, dt, time, params)
					fontIndex = fontIndex + event.indexInc

					if fontIndex <= 0 then
						fontIndex = totalFound
					end

					if fontIndex > totalFound then
						fontIndex = 1
					end

					local fontName = fontNames[fontIndex]
					exampleText:removeSelf()

					exampleText = createFont(dg, fontName)

					indexText.text = formatIndex(fontIndex)		
					indexText:setReferencePoint(TopLeft)
				end)


local lastUpdateTime = 0

-- register main update listener
Runtime:addEventListener('enterFrame', function(event) 
											local time = event.time
											local dt = (time - lastUpdateTime) / 1000
											
											eventSystem:processEvents(dt, time)
											
											lastUpdateTime = time											
										end)
